lattice_server
Post-quantum Signal key distribution server for the Lattice protocol.
Usage
import 'package:lattice_server/lattice_server.dart';
This package is internal to the Lattice monorepo and is not published to pub.dev.
Part of the Lattice monorepo.
See the documentation for details.
License
BSD 3-Clause. See LICENSE for details.
Libraries
- lattice_server
- Post-quantum Signal key distribution server for the Lattice protocol.