lattice_server library

Post-quantum Signal key distribution server for the Lattice protocol.

Classes

FileStorage
File-based persistent storage backend.
InMemoryStorage
In-memory storage backend for development and testing.
LatticeServer
The Lattice key distribution server.
MessageRecord
Pending message record stored on the server.
Middleware
Server middleware for the Lattice key distribution server.
PreKeyRecord
Pre-key bundle record stored on the server.
Routes
API route handlers for the Lattice key distribution server.
Storage
Abstract storage interface for the Lattice key distribution server.
UserRecord
User record stored on the server.